@@ -23,36 +23,36 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
     # pylint: disable=too-many-public-methods
 
     def reset(self) -> None:
-        """Reset the analog impedance measurement functionality.
+        """Reset the |AnalogImpedance| functionality.
 
         Raises:
-            DwfLibraryError: An error occurred while executing the reset operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfAnalogImpedanceReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def configure(self, start: bool) -> None:
-        """Configure the analog impedance measurement, and optionally start a measurement.
+        """Configure the |AnalogImpedance| functionality, and optionally start a measurement.
 
         Parameters:
             start (bool): Whether to start the measurement.
 
         Raises:
-            DwfLibraryError: An error occurred while executing the configure operation.
+            DwfLibraryError: An error occurred while executing the *configure* operation.
         """
         result = self.lib.FDwfAnalogImpedanceConfigure(self.hdwf, int(start))
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def status(self) -> DwfState:
-        """Return the status of the analog impedance measurement.
+        """Return the status of the |AnalogImpedance| functionality.
 
         Returns:
             DwfState: The status of the measurement.
 
         Raises:
-            DwfLibraryError: An error occurred while executing the status operation.
+            DwfLibraryError: An error occurred while executing the *status* operation.
         """
         c_status = typespec_ctypes.DwfState()
         result = self.lib.FDwfAnalogImpedanceStatus(self.hdwf, c_status)
@@ -62,16 +62,16 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return status_
 
     def modeSet(self, mode: int) -> None:
-        """Set measurement mode.
+        """Set |AnalogImpedance| measurement mode.
 
         Parameters:
             mode (int): The measurement mode.
 
                 The following modes are defined:
 
-                * 0: W1-C1-DUT-C2-R-GND
-                * 1: W1-C1-R-C2-DUT-GND
-                * 8: |Impedance analyzer:link| for the Analog Discovery
+                * 0 — W1-C1-DUT-C2-R-GND
+                * 1 — W1-C1-R-C2-DUT-GND
+                * 8 — |Impedance analyzer:link| for the Analog Discovery
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -81,16 +81,16 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def modeGet(self) -> int:
-        """Get measurement mode.
+        """Get |AnalogImpedance| measurement mode.
 
         Returns:
             int: The measurement mode.
 
             The following modes are defined:
 
-            * 0: W1-C1-DUT-C2-R-GND
-            * 1: W1-C1-R-C2-DUT-GND
-            * 8: |Impedance analyzer:link| for the Analog Discovery
+            * 0 — W1-C1-DUT-C2-R-GND
+            * 1 — W1-C1-R-C2-DUT-GND
+            * 8 — |Impedance analyzer:link| for the Analog Discovery
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -103,7 +103,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return mode
 
     def referenceSet(self, reference: float) -> None:
-        """Set reference load value, in Ohms.
+        """Set |AnalogImpedance| reference load value, in Ohms.
 
         Parameters:
             reference (float): The reference load, in Ohms.
@@ -116,7 +116,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def referenceGet(self) -> float:
-        """Get reference load value, in Ohms.
+        """Get |AnalogImpedance| reference load value, in Ohms.
 
         Returns:
             float: The reference load, in Ohms.
@@ -132,7 +132,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return reference
 
     def frequencySet(self, frequency: float) -> None:
-        """Set source frequency, in Hz
+        """Set |AnalogImpedance| source frequency, in Hz.
 
         Parameters:
             frequency (float): The source frequency, in Hz.
@@ -145,7 +145,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def frequencyGet(self) -> float:
-        """Get source frequency, in Hz.
+        """Get |AnalogImpedance| source frequency, in Hz.
 
         Returns:
             float: The source frequency, in Hz.
@@ -161,7 +161,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return frequency
 
     def amplitudeSet(self, amplitude: float) -> None:
-        """Set source amplitude value, in Volts.
+        """Set |AnalogImpedance| source amplitude value, in Volts.
 
         Parameters:
             amplitude (float): The source amplitude, in Volts.
@@ -174,7 +174,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def amplitudeGet(self) -> float:
-        """Get source amplitude, in Volts.
+        """Get |AnalogImpedance| source amplitude, in Volts.
 
         Returns:
             float: The source amplitude, in Volts.
@@ -190,7 +190,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return amplitude
 
     def offsetSet(self, offset: float) -> None:
-        """Set source offset, in Volts.
+        """Set |AnalogImpedance| source offset, in Volts.
 
         Parameters:
             offset (float): The source offset, in Volts.
@@ -203,7 +203,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def offsetGet(self) -> float:
-        """Get source offset, in Volts.
+        """Get |AnalogImpedance| source offset, in Volts.
 
         Returns:
             float: The source offset, in Volts.
@@ -219,7 +219,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return offset
 
     def probeSet(self, resistance: float, capacitance: float) -> None:
-        """Set probe parameters.
+        """Set |AnalogImpedance| probe parameters.
 
         Parameters:
             resistance (float): The probe resistance, in Ohms.
@@ -233,7 +233,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def probeGet(self) -> Tuple[float, float]:
-        """Get probe parameters.
+        """Get |AnalogImpedance| probe parameters.
 
         Returns:
             Tuple[float, float]:
@@ -252,7 +252,10 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return (resistance, capacity)
 
     def periodSet(self, period: int) -> None:
-        """Set the measurement period.
+        """Set the |AnalogImpedance| measurement period.
+
+        Todo:
+            Figure out what this setting is for, why it's an *int*, and what its physical unit is.
 
         Parameters:
             period (int): The measurement period.
@@ -265,8 +268,10 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def periodGet(self) -> int:
-        """Get the measurement period.
+        """Get the |AnalogImpedance| measurement period.
 
+        Todo:
+            Figure out what this setting is for, why it's an *int*, and what its physical unit is.
 
         Returns:
             int: The measurement period.
@@ -282,7 +287,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return period
 
     def compReset(self) -> None:
-        """Reset the measurement computation.
+        """Reset the |AnalogImpedance| measurement computation.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -294,7 +299,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
 
     def compSet(self, open_resistance: float, open_reactance: float,
                 short_resistance: float, short_reactance: float) -> None:
-        """Set the measurement computation parameters.
+        """Set the |AnalogImpedance| measurement computation parameters.
 
         Parameters:
             open_resistance (float): The open-circuit resistance, in Ohms.
@@ -315,7 +320,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def compGet(self) -> Tuple[float, float, float, float]:
-        """Get the measurement computation parameters.
+        """Get the |AnalogImpedance| measurement computation parameters.
 
         Returns:
             Tuple[float, float, float, float]: The open-circuit resistance, open-circuit reactance,
@@ -343,7 +348,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return (open_resistance, open_reactance, short_resistance, short_reactance)
 
     def statusInput(self, channel_index: int) -> Tuple[float, float]:
-        """Get the input measurement status.
+        """Get the |AnalogImpedance| input measurement status.
 
         Parameters:
             channel_index(int): The channel for which to get gain and phase information.
@@ -368,7 +373,7 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         return (gain, radian)
 
     def statusMeasure(self, measure: DwfAnalogImpedance) -> float:
-        """Retrieve the measurement status value.
+        """Retrieve the |AnalogImpedance| measurement status value.
 
         Parameters:
             measure (DwfAnalogImpedance): The quantity to measure.
