@@ -1152,7 +1152,9 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         """Get the |AnalogIn| instrument trigger source info.
 
         Warning:
-            This method is obsolete. Use the generic |DwfDevice.triggerInfo:link| method instead.
+            **This method is obsolete.**
+
+            Use the generic |DwfDevice.triggerInfo:link| method instead.
 
         Returns:
             List[DwfTriggerSource]: A list of trigger sources that can be selected.
