@@ -27,9 +27,9 @@ class AnalogIO(AbstractDwfDeviceSubApi):
     """
 
     def reset(self) -> None:
-        """Reset and configure all |AnalogIO| parameters to default values.
+        """Reset and configure all |AnalogIO| settings to default values.
 
-        If auto-configure is enabled, the changes take immediate effect.
+        If auto-configure is enabled, the changes take effect immediately.
 
         Raises:
             DwfLibraryError: An error occurred while executing the *reset* operation.
@@ -41,6 +41,9 @@ class AnalogIO(AbstractDwfDeviceSubApi):
     def configure(self) -> None:
         """Configure the |AnalogIO| functionality.
 
+        This method transfers the settings to the Digilent Waveforms device. It is not needed
+        if auto-configure is enabled.
+
         Raises:
             DwfLibraryError: An error occurred while executing the *configure* operation.
         """
@@ -51,7 +54,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
     def status(self) -> None:
         """Read the status of the device and stores it internally.
 
-        The following status methods will return the information that was read from the device
+        The status inquiry methods that follow will return the information that was read from the device
         when this method was last called.
 
         Note that the |AnalogIO| functionality is not managed by a state machine,
@@ -65,18 +68,20 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def enableInfo(self) -> Tuple[bool, bool]:
-        """Verify if Master Enable Setting and/or Master Enable Status are supported.
+        """Verify if *Master Enable* and/or *Master Enable Status* are supported.
 
-        The Master Enable setting is essentially a software switch that "enables" or "turns on" the |AnalogIO| channels.
+        The *Master Enable* is a software switch that enable the |AnalogIO| voltage sources.
 
-        If supported, the current status of this Master Enable switch (Enabled/Disabled) can be queried by calling the
-        :py:meth:`enableStatus` method.
+        If supported, the current value of this *Master Enable* switch (Enabled/Disabled) can be
+        set by the :py:meth:`enableSet` method and queried by the :py:meth:`enableGet` method.
 
-        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an over-current protection
-        circuit has been triggered.
+        The *Master Enable Status* that can be queried by the :py:meth:`enableStatus` method may
+        be different from the *Master Enable* value if e.g. an over-current protection circuit
+        has been triggered.
 
-        Returns: Tuple[bool, bool]:
-            The elements indicate whether Master Enable *set* and *status* are supported by the |AnalogIO| device.
+        Returns:
+            Tuple[bool, bool]: The tuple elements indicate whether *Master Enable Set* and
+            *Master Enable Status*, respectively, are supported by the |AnalogIO| device.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -91,10 +96,10 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return (set_supported, status_supported)
 
     def enableSet(self, master_enable: bool) -> None:
-        """Set the master enable switch.
+        """Set value of the *Master Enable* setting.
 
         Parameters:
-            master_enable (bool): The new value of the Master Enable setting.
+            master_enable (bool): The new value of the *Master Enable* setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -104,12 +109,10 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def enableGet(self) -> bool:
-        """Return the current state of the master enable switch.
-
-        This is not obtained from the device.
+        """Return the current value of the *Master Enable* setting.
 
         Returns:
-            The value of the Master Enable setting.
+            The value of the *Master Enable* setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -122,13 +125,13 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return master_enable
 
     def enableStatus(self) -> bool:
-        """Return the actual master enable status (if the device supports it).
+        """Return the actual *Master Enable Status* value (if the device supports it).
 
-        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an over-current protection
-        circuit has been triggered.
+        The *Master Enable Status* value may be different from the *Master Enable* setting if
+        e.g. an over-current protection circuit has been triggered.
 
         Returns:
-            bool: the current status of the Master Enable.
+            bool: the current status of the *Master Enable* circuit.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -157,10 +160,11 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return channel_count
 
     def channelName(self, channel_index: int) -> Tuple[str, str]:
-        """Return the name (long text) and label (short text, printed on the device) for a channel.
+        """Return the name (long text) and label (short text, printed on the device) for the
+        specified |AnalogIO| channel.
 
         Parameters:
-            channel_index (int): The channel from which we want to get the name and label.
+            channel_index (int): The channel for which we want to get the name and label.
 
         Returns:
             Tuple[str, str]: The name and label of the channel.
@@ -182,10 +186,10 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return (channel_name, channel_label)
 
     def channelInfo(self, channel_index: int) -> int:
-        """Return the number of nodes associated with the specified channel.
+        """Return the number of nodes associated with the specified |AnalogIO| channel.
 
         Parameters:
-            channel_index (int): The channel from which we want to get the number of associated nodes.
+            channel_index (int): The channel for which we want to get the number of associated nodes.
 
         Returns:
             int: The number of nodes associated to the channel.
@@ -200,7 +204,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return c_node_count.value
 
     def channelNodeName(self, channel_index: int, node_index: int) -> Tuple[str, str]:
-        """Return the node name ("Voltage", "Current", …) and units ("V", "A", …) for an |AnalogIO| node.
+        """Return the node name ("Voltage", "Current", …) and units ("V", "A", …) for the specified |AnalogIO| node.
 
         Parameters:
             channel_index (int): The channel from which we want to get the name and unit.
@@ -227,14 +231,15 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return (node_name, node_units)
 
     def channelNodeInfo(self, channel_index: int, node_index: int) -> DwfAnalogIO:
-        """Return the supported channel node modes.
+        """Return the type of physical quantity (e.g., voltage, current, or temperature)
+        represented by the specified |AnalogIO| channel node.
 
         Parameters:
-            channel_index (int): The channel from which we want to get the quantity type.
-            node_index (int): The node from which we want to get the quantity type.
+            channel_index (int): The channel from which we want to get the type of physical quantity.
+            node_index (int): The node from which we want to get the type of physical quantity.
 
         Returns:
-            DwfAnalogIO: The type of quantity represented by the node.
+            DwfAnalogIO: The type of physical quantity represented by the node.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -251,20 +256,20 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return analog_io
 
     def channelNodeSetInfo(self, channel_index: int, node_index: int) -> Tuple[float, float, int]:
-        """Return node value limits.
+        """Return the limits of the value that can be assigned to the specified |AnalogIO| channel node.
 
         Since a node can represent many things (power supply, temperature sensor, etc.),
         the *minimum*, *maximum*, and *steps* parameters also represent different types of values.
 
-        :py:meth:`channelNodeInfo` returns the type of values to expect and :py:meth:`channelNodeName`
-        returns the units of these values.
+        The :py:meth:`channelNodeInfo` method returns the type of values to expect and the
+        :py:meth:`channelNodeName` method returns the units of these values.
 
         Parameters:
             channel_index (int): The channel from which we want to get the currently configured value.
             node_index (int): The node from which we want to get the currently configured value.
 
         Returns:
-            Tuple[float, float, int]: the minimum and maximum values for the specified node's value,
+            Tuple[float, float, int]: The minimum and maximum values for the specified node's value,
             and the number of resolution steps.
 
         Raises:
@@ -288,7 +293,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return (min_value, max_value, num_steps)
 
     def channelNodeSet(self, channel_index: int, node_index: int, node_value: float) -> None:
-        """Set the node value for the specified node on the specified channel.
+        """Set the node value for the specified |AnalogIO| channel node.
 
         Parameters:
             channel_index (int): The channel for which we want to set the value.
@@ -307,11 +312,11 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelNodeGet(self, channel_index: int, node_index: int) -> float:
-        """Return the currently set value of the node on the specified channel.
+        """Return the current value of the specified |AnalogIO| channel node.
 
         Parameters:
-            channel_index (int): The channel from which we want to get the currently configured value.
-            node_index (int): The node from which we want to get the currently configured value.
+            channel_index (int): The channel from which we want to get the current value.
+            node_index (int): The node from which we want to get the current value.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -328,14 +333,14 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return node_value
 
     def channelNodeStatusInfo(self, channel_index: int, node_index: int) -> Tuple[float, float, int]:
-        """Return the range of status values available for the specified node on the specified channel.
+        """Return the range of status values for the specified |AnalogIO| channel node.
 
         Parameters:
             channel_index (int): The channel from which we want to get status information.
             node_index (int): The node from which we want to get status information.
 
         Returns:
-            Tuple[float, float, int]: the minimum and maximum status values for the specified node,
+            Tuple[float, float, int]: The minimum and maximum status values for the specified node,
             and the number of resolution steps.
 
         Raises:
@@ -359,12 +364,12 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         return (min_value, max_value, num_steps)
 
     def channelNodeStatus(self, channel_index: int, node_index: int) -> float:
-        """Return the most recent status value reading of the node.
+        """Return the most recent status value reading of the specified |AnalogIO| channel node.
 
         To fetch updated values for all |AnalogIO| nodes, use the :py:meth:`status` method.
 
         Returns:
-            float: the most recent value read for this nodes.
+            float: The most recent value read for this channel node.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
