@@ -93,7 +93,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
             bool: True if the Digilent Waveforms device is already opened, False otherwise.
 
         Raises:
-            DwfLibraryError: The open state of the Digilent Waveforms device cannot be retrieved.
+            DwfLibraryError: The open state of the Digilent Waveforms device cannot be determined.
         """
         c_is_used = typespec_ctypes.c_int()
         result = self.lib.FDwfEnumDeviceIsOpened(device_index, c_is_used)
@@ -196,7 +196,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return config_count
 
     def _configInfoString(self, config_index: int, info: DwfEnumConfigInfo, max_size: int) -> str:
-        """Return Digilent Waveforms device configuration info for strings."""
+        """Return device configuration information for parameters that return a string value."""
 
         c_configuration_parameter_value = ctypes.create_string_buffer(max_size)
         result = self.lib.FDwfEnumConfigInfo(
@@ -208,7 +208,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return configuration_parameter_value
 
     def configInfo(self, config_index: int, info: DwfEnumConfigInfo) -> Union[int, str]:
-        """Return information about Digilent Waveforms device configuration.
+        """Return information about a Digilent Waveforms device configuration.
 
         Parameters:
             config_index (int): Zero-based index of the previously enumerated configuration
@@ -216,11 +216,18 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
 
             info (DwfEnumConfigInfo): Selects which configuration parameter to retrieve.
 
+        Note:
+            For most values of the *info* parameter, this method returns an integer, but for some values
+            it returns a string. Refer to the |DwfEnumConfigInfo:link| documentation for details.
+
+            This explains the somewhat unusual *Union[int, str]* return type of this method.
+
         Returns:
             Union[int, str]: The value of the selected configuration parameter, of the selected configuration.
 
         Raises:
-            DwfLibraryError: The configuration info of the Digilent Waveforms device cannot be retrieved.
+            DwfLibraryError: The requested configuration information of the Digilent Waveforms device cannot be
+                retrieved.
         """
 
         if info == DwfEnumConfigInfo.TooltipText:
@@ -240,7 +247,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         """Return the analog input channel count of the selected Digilent Waveforms device.
 
         Warning:
-            This method is obsolete.
+            **This method is obsolete.**
 
             Use either of the following instead:
 
@@ -269,7 +276,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         """Retrieve the analog input buffer size of the selected Digilent Waveforms device.
 
         Warning:
-            This method is obsolete.
+            **This method is obsolete.**
 
             Use either of the following instead:
 
@@ -298,7 +305,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         """Retrieve the analog input bit resolution of the selected Digilent Waveforms device.
 
         Warning:
-            This method is obsolete.
+            **This method is obsolete.**
 
             Use |AnalogIn.bitsInfo:link| instead.
 
@@ -323,7 +330,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         """Retrieve the analog input sample frequency of the selected Digilent Waveforms device.
 
         Warning:
-            This method is obsolete.
+            **This method is obsolete.**
 
             Use |AnalogIn.frequencyInfo:link| instead.
 
