@@ -28,11 +28,16 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def clear(self) -> int:
+    def clear(self) -> bool:
         """Clear the I²C bus.
 
+        Verify and try to solve an I²C bus lockup condition.
+
+        Todo:
+            The precise behavior of this method needs to be understood and documented.
+
         Returns:
-            int: A "bus free" indicator.
+            bool: True if the bus is clear after the operation, False otherwise.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -41,12 +46,15 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         result = self.lib.FDwfDigitalI2cClear(self.hdwf, c_bus_free)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        bus_free = c_bus_free.value
+        bus_free = bool(c_bus_free.value)
         return bus_free
 
     def stretchSet(self, stretch_enable: int) -> None:
         """Set I²C stretch behavior.
 
+        Todo:
+            The precise behavior of this method needs to be understood and documented.
+
         Parameters:
             stretch_enable (bool): True to enable stretch, False to disable.
 
@@ -74,6 +82,9 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
     def readNakSet(self, nak_last_read_byte: int) -> None:
         """Set read NAK state.
 
+        Todo:
+            The precise behavior of this method needs to be understood and documented.
+
         Parameters:
             nak_last_read_byte (int): (undocumented)
 
@@ -85,7 +96,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sclSet(self, channel_index: int) -> None:
-        """Set the channel where the clock (SCL) signal is transmitted.
+        """Set the digital channel (pin) where the clock (SCL) signal is transmitted.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to generate the SCL clock.
@@ -98,7 +109,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def sdaSet(self, channel_index: int) -> None:
-        """Set the channel where the data (SDA) signal is transmitted/received.
+        """Set the digital channel (pin) where the data (SDA) signal is transmitted/received.
 
         Parameters:
             channel_index (int): The channel (digital pin number) on which to send/receive SDA data.
@@ -114,13 +125,13 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Perform an I²C combined write/read operation.
 
         Parameters:
-            address (int): Address of the target device.
-            tx (List[int]): Words to send.
-            number_of_rx_bytes (int): Number of octets to receive.
+            address (int): The I²C address of the target device.
+            tx (List[int]): The octets to send.
+            number_of_rx_bytes (int): The number of octets to receive.
 
         Returns:
             Tuple[int, List[int]:
-                The first element is the NAK indication; the second element is a list of values received.
+                The first element is the NAK indication; the second element is a list of octet values received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -158,12 +169,12 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Perform an I²C read operation.
 
         Parameters:
-            address (int): Address of the target device.
-            number_of_words (int): Number of octets to receive.
+            address (int): The I²C address of the target device.
+            number_of_words (int): The number of octets to receive.
 
         Returns:
             Tuple[int, List[int]:
-                The first element is the NAK indication; the second element is a list of values received.
+                The first element is the NAK indication; the second element is a list of octet values received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -189,11 +200,11 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Perform an I²C write operation.
 
         Parameters:
-            address (int): Address of the target device.
-            tx (List[int]): Words to send.
+            address (int): The I²C address of the target device.
+            tx (List[int]): The octets to send.
 
         Returns:
-            int: NAK indication.
+            int: The NAK indication.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -221,11 +232,11 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Perform an I²C write operation of a single octet.
 
         Parameters:
-            address (int): Address of the target device.
-            tx (int): Word to send.
+            address (int): The I²C address of the target device.
+            tx (int): The single octet to send.
 
         Returns:
-            int: NAK indication.
+            int: The NAK indication.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
