@@ -46,7 +46,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def configure(self, reconfigure: bool, start: bool) -> None:
-        """Configure the |DigitalIn| instrument.
+        """Configure the instrument and start or stop the acquisition operation.
 
         Parameters:
             reconfigure (bool): If True, the instrument settings are sent to the instrument.
@@ -60,7 +60,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     def status(self, read_data_flag: bool) -> DwfState:
-        """Get |DigitalIn| instrument status.
+        """Get |DigitalIn| instrument state.
 
         Parameters:
             read_data_flag (bool): Whether to read data.
@@ -85,7 +85,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     ####################################################################################################################
 
     def statusTime(self) -> Tuple[int, int, int]:
-        """Get the |DigitalIn| status timestamp.
+        """Get the timestamp of the current status information.
 
         Returns:
             Tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
@@ -114,7 +114,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return (sec_utc, tick, ticks_per_second)
 
     def statusAutoTriggered(self) -> bool:
-        """Verify if the |DigitalIn| acquisition is auto triggered.
+        """Check if the current acquisition is auto-triggered.
 
         Returns:
             bool: True if the current acquisition is auto-triggered, False otherwise.
@@ -130,7 +130,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return auto_triggered
 
     def statusSamplesLeft(self) -> int:
-        """Retrieve the number of samples left in the |DigitalIn| acquisition.
+        """Retrieve the number of samples left in the acquisition, in samples.
 
         Returns:
             int: In case a finite-duration acquisition is active, the number of samples
@@ -147,7 +147,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return samplesLeft
 
     def statusSamplesValid(self) -> int:
-        """Retrieve the number of valid/acquired |DigitalIn| data samples.
+        """Retrieve the number of valid/acquired data samples.
 
         Returns:
             int: The number of valid samples.
@@ -163,7 +163,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return samples_valid
 
     def statusIndexWrite(self) -> int:
-        """Retrieve the |DigitalIn| buffer write pointer.
+        """Retrieve the buffer write index.
 
         This is needed in :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.ScanScreen`
         acquisition mode to display the scan bar.
@@ -182,7 +182,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return index_write
 
     def statusRecord(self) -> Tuple[int, int, int]:
-        """Get the |DigitalIn| recording status.
+        """Get the recording status.
 
         Returns:
             Tuple[int, int, int]: A three-element tuple containing the counts for
@@ -292,7 +292,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return hzFreq
 
     def clockSourceInfo(self) -> List[DwfDigitalInClockSource]:
-        """Get the valid |DigitalIn| clock sources.
+        """Get the valid clock sources for the |DigitalIn| instrument.
 
         Returns:
             List[DwfDigitalInClockSource]: A list of valid clock sources.
@@ -484,14 +484,15 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     def inputOrderSet(self, dio_first: bool) -> None:
         """Configure the |DigitalIn| order of values stored in the sampling array.
 
-        If dio_first is True, DIO 24..39 are placed at the beginning of the array followed by DIN 0..23.
-        If dio_first is False, DIN 0..23 are placed at the beginning followed by DIO 24..31.
+        If *dio_first* is True, DIO 24…39 are placed at the beginning of the array followed by DIN 0…23.
+
+        If *dio_first* is False, DIN 0…23 are placed at the beginning followed by DIO 24…31.
+
+        This method is valid only for the Digital Discovery device.
 
         Parameters:
             dio_first (bool): Whether the DIO pins come before the DIN pins.
 
-        Valid only for the Digital Discovery device.
-
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
@@ -666,8 +667,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     def triggerSourceInfo(self) -> List[DwfTriggerSource]:
         """Get the valid |DigitalIn| instrument trigger sources.
 
-        Note:
-            This method is obsolete. Use the generic :py:meth:`DeviceControl.triggerInfo()` method instead.
+        Warning:
+            **This method is obsolete.**
+
+            Use the generic :py:meth:`DeviceControl.triggerInfo()` method instead.
 
         Returns:
             List[DwfTriggerSource]: A list of valid trigger sources.
@@ -1002,14 +1005,14 @@ class DigitalIn(AbstractDwfDeviceSubApi):
     def mixedSet(self, enable: bool) -> None:
         """Set mixed state.
 
-        Parameters:
-            enable (bool): (to be documented)
+        Warning:
+            **This method is obsolete.**
 
         Todo:
             Figure out what this setting does.
 
-        Note:
-            This method is obsolete.
+        Parameters:
+            enable (bool): (to be documented)
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
