@@ -23,10 +23,9 @@ class DigitalIO(AbstractDwfDeviceSubApi):
     def reset(self) -> None:
         """Reset all |DigitalIO| settings to default values.
 
-        It sets the outputs to tri-state (high impedance, not enabled), output value to zero,
-        and configures the |DigitalIO|.
+        It sets the digital pins to tri-state (high impedance, not enabled) and output value to zero.
 
-        If auto-configure is enabled, the values are immediately effectuated.
+        If auto-configure is enabled, the values are immediately applied.
 
         Raises:
             DwfLibraryError: An error occurred while executing the *reset* operation.
@@ -38,7 +37,8 @@ class DigitalIO(AbstractDwfDeviceSubApi):
     def configure(self) -> None:
         """Configure the |DigitalIO| functionality.
 
-        This method does not have to be used if auto-configuration is enabled.
+        This method transfers the settings to the Digilent Waveforms device. It is not needed
+        if auto-configure is enabled.
 
         Raises:
             DwfLibraryError: An error occurred while executing the *configure* operation.
