@@ -329,8 +329,10 @@ class DigitalOut(AbstractDwfDeviceSubApi):
     def triggerSourceInfo(self) -> List[DwfTriggerSource]:
         """Get the valid |DigitalOut| trigger sources.
 
-        Note:
-            This method is obsolete. Use the generic DeviceControl.triggerInfo() method instead.
+        Warning:
+            **This method is obsolete.**
+
+            Use the generic DeviceControl.triggerInfo() method instead.
 
         Returns:
             List[DwfTriggerSource]: A list of valid the trigger sources.
