@@ -1,4 +1,4 @@
-"""The *pydwf.core.dwf_device_subapi* module implements a single class: *AbstractDwfDeviceSubApi*."""
+"""The |pydwf.core.dwf_device_subapi| module implements a single class: |AbstractDwfDeviceSubApi|."""
 
 from typing import TYPE_CHECKING
 
@@ -7,14 +7,14 @@ if TYPE_CHECKING:
 
 
 class AbstractDwfDeviceSubApi:
-    """Abstract base class for the sub-API class members of a |DwfDevice|."""
+    """Abstract base class for the sub-API attributes of a |DwfDevice|."""
 
     def __init__(self, device: 'DwfDevice'):
         self._device = device
 
     @property
     def device(self):
-        """Return the |DwfDevice| of which we are an attribute.
+        """Return the |DwfDevice| instance of which we are an attribute.
 
         This is useful if we have a variable that contains a reference to a |DwfDevice| attribute,
         but we need the |DwfDevice| itself.
@@ -28,13 +28,19 @@ class AbstractDwfDeviceSubApi:
     def hdwf(self):
         """Return the HDWF device handle.
 
+        Returns:
+            int: The HDWF device handle.
+
         :meta private:
         """
         return self.device.hdwf
 
     @property
     def dwf(self):
-        """Return the library.
+        """Return the |DwfLibrary| instance.
+
+        Returns:
+            DwfLibrary: The |DwfLibrary| instance.
 
         :meta private:
         """
@@ -42,7 +48,10 @@ class AbstractDwfDeviceSubApi:
 
     @property
     def lib(self):
-        """Return the *ctypes* library.
+        """Return the |ctypes:link| library.
+
+        Returns:
+            ctypes.CDLL: The |ctypes| library.
 
         :meta private:
         """
