@@ -99,7 +99,7 @@ class DwfLibrary:
     def lib(self) -> ctypes.CDLL:
         """Return the |ctypes:link| shared library instance used to access the DWF library.
 
-        This property is primarily provided for internal |pydwf| use.
+        This property is provided for internal |pydwf| use.
 
         :meta private:
         """
@@ -110,13 +110,13 @@ class DwfLibrary:
         """Add |ctypes:link| return type and parameter type annotations for all known functions in the DWF
         shared library.
 
-        This function uses a list of DWF function signatures derived from the *dwf.h* C header file to perform
+        This method uses a list of DWF function signatures derived from the *dwf.h* C header file to perform
         the type annotation.
 
         Parameters:
             lib (ctypes.CDLL): The shared library whose functions will be type-annotated.
 
-        This method is intended exclusively for internal |pydwf| use by the :py:meth:`__init__` method.
+        This method is used exclusively by the :py:meth:`__init__` method.
         """
 
         function_signatures = dwf_function_signatures(typespec_ctypes)
@@ -143,7 +143,7 @@ class DwfLibrary:
         Note that this method *returns* an exception instance; it doesn't *raise* it.
 
         Returns:
-            DwfLibraryError: an exception describing the error reported by the last DWF library call.
+            DwfLibraryError: An exception describing the error reported by the last DWF library call.
 
         :meta private:
         """
@@ -188,7 +188,7 @@ class DwfLibrary:
         Returns:
             str: The error message of the last API call.
 
-            The description may consist of multiple of messages, separated by a newline character,
+            The string may consist of multiple messages, separated by a newline character,
             that describe the events leading to the error.
 
         Raises:
@@ -224,16 +224,20 @@ class DwfLibrary:
         Device parameters are settings of a specific |DwfDevice|.
         Refer to the |device parameters:link| section for more information.
 
-        This method sets a default device parameter value to be used for for devices that are
+        This method sets a default device parameter value to be used for devices that are
         opened subsequently.
 
+        See Also:
+            To set the parameter value of a specific |DwfDevice|, use the
+            :py:meth:`DwfDevice.paramSet <pydwf.core.DwfDevice.paramSet>` method.
+
         Warning:
             The device parameter values are not checked to make sure they correspond to a valid
             value for the specific device parameter.
 
         Parameters:
-            device_parameter (DwfDeviceParameter): The device parameter for which to set the value.
-            value (int): The desired device parameter value.
+            device_parameter (DwfDeviceParameter): The device parameter for which to set the default value.
+            value (int): The default device parameter value.
 
         Raises:
             DwfLibraryError: The device parameter value cannot be set.
@@ -248,9 +252,13 @@ class DwfLibrary:
         Device parameters are settings of a specific |DwfDevice|.
         Refer to the |device parameters:link| section for more information.
 
-        This method retrieves device parameter values at the library level.
+        This method retrieves device parameter values at the library level (i.e., not tied to a specific device).
         They are used as default device parameter values for devices that are opened subsequently.
 
+        See Also:
+            To get the parameter value of a specific |DwfDevice|, use the
+            :py:meth:`DwfDevice.paramGet <pydwf.core.DwfDevice.paramGet>` method.
+
         Parameters:
             device_parameter (DwfParameter): The device parameter for which to get the value.
 
