@@ -7,21 +7,28 @@ if TYPE_CHECKING:
 
 
 class AbstractDwfLibrarySubApi:
-    """Abstract base class for the sub-API class members of a |DwfLibrary|."""
+    """Abstract base class for the sub-API attributes of a |DwfLibrary|."""
 
     def __init__(self, dwf: 'DwfLibrary'):
         self._dwf = dwf
 
     @property
     def dwf(self):
-        """Return the library.
+        """Return the |DwfLibrary| instance of which we are an attribute.
+
+        Returns:
+            DwfLibrary: The |DwfLibrary| instance.
+
         :meta private:
         """
         return self._dwf
 
     @property
     def lib(self):
-        """Return the |ctypes| library.
+        """Return the |ctypes:link| library.
+
+        Returns:
+            ctypes.CDLL: The |ctypes| library.
 
         :meta private:
         """
