@@ -11,8 +11,8 @@ from pydwf.core.auxiliary.exceptions import PyDwfError
 def openDwfDevice(
             dwf: DwfLibrary,
             enum_filter: Optional[DwfEnumFilter] = None,
-            serial_number: Optional[str] = None,
-            score_func: Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[int]]] = None
+            serial_number_filter: Optional[str] = None,
+            score_func: Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[Any]]] = None
         ) -> DwfDevice:
     """Open a device identified by its serial number, optionally selecting a preferred configuration.
 
@@ -22,12 +22,12 @@ def openDwfDevice(
 
        To do this, device enumeration is performed, resulting in a list of all reachable Digilent Waveforms devices.
 
-       For this initial enumeration process the *enum_filter* can be used to only list certain types of devices
-       (for example, only Analog Discovery 2 devices, or Digital Discovery devices). If omitted (the default),
-       all Digilent Waveforms devices will be listed.
+       For this initial enumeration process the *enum_filter* parameter can be used to only list certain types of
+       devices (for example, only Analog Discovery 2 devices, or Digital Discovery devices).
+       If omitted (the default), all Digilent Waveforms devices will be listed.
 
-       Then, if the *serial_number* parameter is given, the list will be filtered to exclude devices whose serial
-       numbers do not match.
+       Then, if the *serial_number_filter* parameter is given, the list will be filtered to exclude devices whose
+       serial numbers do not match.
 
        If the list that remains has a single device, this device will be used. If not, a |PyDwfError:link| is raised.
 
@@ -36,14 +36,14 @@ def openDwfDevice(
        For many use cases, the default configuration that provides a balanced tradeoff works fine.
        If no *score_func* is provided, this default configuration will be used.
 
-       If a *score_func* is provided, it should be a function (or lambda expression) that
+       If a *score_func* parameter is provided, it should be a function (or lambda expression) that
        takes a single parameter *configuration_info*, which is a dictionary with |DwfEnumConfigInfo:link| keys,
        and parameters values for a specific device configuration.
 
-       The *score_func* should return *None* if the configuration is entirely unsuitable, or otherwise a score
-       that reflects the suitability of that particular configuration for the task at hand.
+       The *score_func* should return None if the configuration is entirely unsuitable, or otherwise a score that
+       reflects the suitability of that particular configuration for the task at hand.
 
-       The *openDwfDevice* function will go through all available device configurations, construct a dictionary
+       The *openDwfDevice* method will go through all available device configurations, construct a dictionary
        of all parameters that describe the configuration, call the *score_func* with that dictionary as a parameter,
        and examine the score value it returns. If multiple suitable device configurations are found (i.e., the
        *score_func* does not return None), it will select the configuration with the highest score.
@@ -75,10 +75,11 @@ def openDwfDevice(
         dwf (DwfLibrary): The |DwfLibrary:link| used to open the device.
         enum_filter (Optional[DwfEnumFilter]):
             An optional filter to limit the device enumeration to certain device types.
-            In None, enumerate all devices.
-        serial_number (str): The serial number of the device to be opened.
-            Digilent Waveforms device serial numbers consist of 12 hexadecimal digits.
-        score_func (Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[int]]]):
+            If None, enumerate all devices.
+        serial_number_filter (str): The serial number filter used to select a specific device.
+            A device is considered to match if its 12-digit serial number ends with the serial number filter string
+            (case is ignored).
+        score_func (Optional[Callable[[Dict[DwfEnumConfigInfo, Any]], Optional[Any]]]):
             A function to score a configuration of the selected device.
             See the description above for details.
 
@@ -99,19 +100,20 @@ def openDwfDevice(
     # We do the explicit conversion to list to make sure the variable is a list of integers, not a range.
     candidate_devices = list(range(num_devices))
 
-    if serial_number is not None:
+    if serial_number_filter is not None:
 
-        candidate_devices = [device_index for device_index in candidate_devices
-                             if dwf.deviceEnum.serialNumber(device_index) == serial_number]
+        candidate_devices = [
+            device_index for device_index in candidate_devices
+            if dwf.deviceEnum.serialNumber(device_index).casefold().endswith(serial_number_filter.casefold())]
 
         if len(candidate_devices) == 0:
-            raise PyDwfError("No Digilent Waveforms device found in device class '{}' with serial number '{}'.".format(
-                enum_filter.name, serial_number))
+            raise PyDwfError("No Digilent Waveforms device found"
+                " in device class '{}' with serial number filter '{}'.".format(enum_filter.name, serial_number_filter))
 
         if len(candidate_devices) > 1:
-            # Multiple devices found with a matching serial number; this should not happen!
-            raise PyDwfError("Multiple Digilent Waveforms devices found with serial number '{}'.".format(
-                serial_number))
+            # Multiple devices found with a matching serial number.
+            raise PyDwfError("Multiple Digilent Waveforms devices found"
+                " in device class '{}' with serial number filter '{}'.".format(enum_filter.name, serial_number_filter))
 
     else:
 
@@ -121,13 +123,11 @@ def openDwfDevice(
         if len(candidate_devices) > 1:
             raise PyDwfError(
                 "Multiple Digilent Waveforms devices found (serial numbers: {});"
-                " specify a serial number to select one.".format(
+                " specify a serial number filter to select one.".format(
                     ", ".join(dwf.deviceEnum.serialNumber(device_index) for device_index in candidate_devices)))
 
     # We now have a single candidate device left.
 
-    assert len(candidate_devices) == 1
-
     device_index = candidate_devices[0]
 
     if score_func is None:
